
:autogenerated:

krotov.optimize module
======================

.. currentmodule:: krotov.optimize

.. automodule:: krotov.optimize
    :members: optimize_pulses
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        optimize_pulses





    ``__all__``: :func:`optimize_pulses <krotov.optimize.optimize_pulses>`



    Reference
    ---------